@@ -62,6 +62,7 @@ class JobSpec(object):
                  'allOkEvents'        : 'at',
                  'notDiscardEvents'   : 'de',
                  'decAttOnFailedES'   : 'df',
+                 'debugMode'          : 'dm',
                  'dynamicNumEvents'   : 'dy',
                  'encJobParams'       : 'ej',
                  'fakeJobToIgnore'    : 'fake',
@@ -73,6 +74,7 @@ class JobSpec(object):
                  'noLoopingCheck'     : 'lc',
                  'mergeAtOs'          : 'mo',
                  'noExecStrCnv'       : 'nc',
+                 'pushStatusChanges'  : 'pc',
                  'putLogToOS'         : 'po',
                  'registerEsFiles'    : 're',
                  'resurrectConsumers' : 'rs',
@@ -80,6 +82,7 @@ class JobSpec(object):
                  'jobCloning'         : 'sc',
                  'scoutJob'           : 'sj',
                  'usePrefetcher'      : 'up',
+                 'useSecrets'         : 'us',
                  'useZipToPin'        : 'uz',
                  'writeInputToFile'   : 'wf',
                  }
@@ -669,7 +672,21 @@ class JobSpec(object):
             items.append(self._tagForSH['useZipToPin'])
         self.specialHandling = ','.join(items)
 
+    # use secrets
+    def use_secrets(self):
+        if self.specialHandling is not None:
+            return self._tagForSH['useSecrets'] in self.specialHandling.split(',')
+        return False
 
+    # set to use secrets
+    def set_use_secrets(self):
+        if self.specialHandling is not None:
+            items = self.specialHandling.split(',')
+        else:
+            items = []
+        if self._tagForSH['useSecrets'] not in items:
+            items.append(self._tagForSH['useSecrets'])
+        self.specialHandling = ','.join(items)
 
     # not discard events
     def notDiscardEvents(self):
@@ -868,3 +885,44 @@ class JobSpec(object):
         if self._tagForSH['encJobParams'] not in items:
             items.append(self._tagForSH['encJobParams'])
         self.specialHandling = ','.join(items)
+
+    # check if debug mode
+    def is_debug_mode(self):
+        if self.specialHandling is not None:
+            items = self.specialHandling.split(',')
+            return self._tagForSH['debugMode'] in items or 'debug' in items
+        return False
+
+    # set debug mode
+    def set_debug_mode(self):
+        if self.specialHandling:
+            items = self.specialHandling.split(',')
+        else:
+            items = []
+        if self._tagForSH['debugMode'] not in items:
+            items.append(self._tagForSH['debugMode'])
+        self.specialHandling = ','.join(items)
+
+    # set push status changes
+    def set_push_status_changes(self):
+        if self.specialHandling:
+            items = self.specialHandling.split(',')
+        else:
+            items = []
+        if self._tagForSH['pushStatusChanges'] not in items:
+            items.append(self._tagForSH['pushStatusChanges'])
+        self.specialHandling = ','.join(items)
+
+    # check if to push status changes
+    def push_status_changes(self):
+        return push_status_changes(self.specialHandling)
+
+
+# utils
+
+# check if to push status changes without class instance
+def push_status_changes(special_handling):
+    if special_handling is not None:
+        items = special_handling.split(',')
+        return JobSpec._tagForSH['pushStatusChanges'] in items
+    return False
